Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\supercube\typ_b.py: 0%

# Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\supercube\typ_b.py : 0%

## 15 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Copyright (c) 2019-2020 ETH Zurich, SIS ID and HVL D-ITET

2#

3"""

4 Supercube Typ B module.

5"""

6

7 from hvl_ccb.configuration import configdataclass

8 from . import constants

9 from .base import (

10 SupercubeBase,

11 SupercubeOpcUaCommunication,

12 SupercubeOpcUaCommunicationConfig,

13)

14

15

16@configdataclass

17 class SupercubeBOpcUaConfiguration(SupercubeOpcUaCommunicationConfig):

18 endpoint_name: str = constants.SupercubeOpcEndpoint.B.value # type: ignore

19

20

21 class SupercubeBOpcUaCommunication(SupercubeOpcUaCommunication):

22 @staticmethod

23 def config_cls():

24 return SupercubeBOpcUaConfiguration

25

26

27 class SupercubeB(SupercubeBase):

28 """

29 Variant B of the Supercube without frequency converter but external safety switches.

30 """

31

32 @staticmethod

33 def default_com_cls():

34 return SupercubeBOpcUaCommunication